@@ -1,12 +1,12 @@
 from __future__ import annotations
 
+import datetime
 import email.utils
 import errno
 import os
 import sys
 import urllib.parse
 from abc import abstractmethod
-from datetime import datetime
 from typing import List, Optional
 
 import attr
@@ -176,7 +176,7 @@ class FileInputSource(InputSource):
         with open(self.sourceName, encoding="utf-8") as f:
             return InputContent(
                 f.readlines(),
-                datetime.fromtimestamp(os.path.getmtime(self.sourceName)).date(),
+                datetime.datetime.fromtimestamp(os.path.getmtime(self.sourceName)).date(),
             )
 
     def hasDirectory(self) -> bool:
