@@ -1,10 +1,11 @@
-import collections
+import collections.abc
 import os
 import re
 
 import lxml
 
 from .. import messages
+from .. import t
 
 
 def englishFromList(items, conjunction="or"):
@@ -149,12 +150,13 @@ def groupFromKey(key, length=2):
         return group
 
 
+_groupFromKeyCache: t.Dict[str, str]
 _groupFromKeyCache = {}
 
 
 def flatten(arr):
     for el in arr:
-        if isinstance(el, collections.Iterable) and not isinstance(el, str) and not lxml.etree.iselement(el):
+        if isinstance(el, collections.abc.Iterable) and not isinstance(el, str) and not lxml.etree.iselement(el):
             yield from flatten(el)
         else:
             yield el
