@@ -12,7 +12,7 @@ def update(path, dryRun=False):
             "https://raw.githubusercontent.com/tabatkins/bikeshed/master/bikeshed/spec-data/readonly/languages.json"
         ).text
     except Exception as e:
-        die("Couldn't download languages data.\n{0}", e)
+        die(f"Couldn't download languages data.\n{e}")
         return
 
     if not dryRun:
@@ -20,6 +20,6 @@ def update(path, dryRun=False):
             with open(os.path.join(path, "languages.json"), "w", encoding="utf-8") as f:
                 f.write(data)
         except Exception as e:
-            die("Couldn't save languages database to disk.\n{0}", e)
+            die(f"Couldn't save languages database to disk.\n{e}")
             return
     say("Success!")
